#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""
Functions for resolving arbitration
Function name must match intervention type
"""
import logging
import time

from . import calls

logger = logging.getLogger("mediator")


def force_fail(url: str, wf_id: int):
    """
    Report whether force fail intervention succeeded or failed

    :return:
    """
    time.sleep(1)
    check_status = calls.get_request(url, wf_id)["state"]
    if check_status == "Failed":
        logger.info(f"Successfully failed workflow request #{wf_id}!")
        logger.info("Resolution complete!")
    else:
        logger.info("Unable to confirm state change. Please check the database.")


def submit(url: str, wf_id: int):
    """
    Report whether submit intervention succeeded or failed

    :return:
    """
    time.sleep(1)
    check_status = calls.get_request(url, wf_id)["state"]
    if check_status != "Created":
        logger.info(f"Successfully submitted workflow request #{wf_id}!")
        logger.info("Resolution complete!")
    else:
        logger.info("Unable for confirm state change. Please check the database.")
